@@ -50,8 +50,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.7_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.7_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.8' "
+                "'--htmldir=/usr/share/doc/python-3.12.8/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -71,9 +71,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -118,7 +118,6 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.cpython-312-aarch64-linux-gnu.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
@@ -1084,7 +1083,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1208,10 +1207,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1241,8 +1240,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
