@@ -50,8 +50,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.8_p1' "
-                "'--htmldir=/usr/share/doc/python-3.12.8_p1/html' "
+                "'--docdir=/usr/share/doc/python-3.12.8' "
+                "'--htmldir=/usr/share/doc/python-3.12.8/html' "
                 "'--libdir=/usr/lib' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -71,9 +71,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -623,15 +623,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.l4se987r/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.capvi6s2/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.l4se987r/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.capvi6s2/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.l4se987r/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.capvi6s2/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.l4se987r/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.capvi6s2/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.l4se987r/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.capvi6s2/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -1087,7 +1087,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1211,10 +1211,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1244,8 +1244,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.8_p1/work/Python-3.12.8',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.12.8/work/Python-3.12.8',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
